@@ -1,17 +1,30 @@
 import re
-from typing import Dict
+from typing import Optional, Dict, Iterable
 
+from sybil import Document, Region
 from sybil.parsers.abstract.lexers import BlockLexer
 
 START_PATTERN_TEMPLATE =(
     r'^(?P<prefix>[ \t]*)\.\.\s*(?P<directive>{directive})'
-    r'({delimiter}\s*'
-    r'(?P<arguments>[\w-]+\b)?'
-    r'(?:\s*\:[\w-]+\:.*\n)*'
-    r'(?:\s*\n)*\n)?'
+    r'{delimiter}[ \t]*'
+    r'(?P<arguments>[^\n]+)?\n'
+    r'(?P<options>(?:\1[ \t]+:[\w-]*:[^\n]*\n)+)?'
 )
 
-END_PATTERN_TEMPLATE = r'(\n\Z|\n[ \t]{{0,{len_prefix}}}(?=\S|\Z))'
+OPTIONS_PATTERN = re.compile(r'[^:]*:(?P<name>[^:]+):[ \t]*(?P<value>[^\n]*)\n')
+END_PATTERN_TEMPLATE = r'(\n?\Z|\n[ \t]{{0,{len_prefix}}}(?=\S|\Z))'
+
+
+def parse_options_and_source(lexed: Region) -> None:
+    lexemes = lexed.lexemes
+    raw_options = lexemes.pop('options', None)
+    options = lexemes['options'] = {}
+    if raw_options:
+        for match in OPTIONS_PATTERN.finditer(raw_options):
+            options[match['name']] = match['value']
+    source = lexemes.get('source')
+    if source:
+        lexemes['source'] = source.strip_leading_newlines()
 
 
 class DirectiveLexer(BlockLexer):
@@ -31,12 +44,17 @@ class DirectiveLexer(BlockLexer):
 
     :param mapping:
         If provided, this is used to rename lexemes from the keys in the mapping to their values.
-        Only mapped lexemes will be returned in any :class:`~sybil.LexedRegion` objects.
+        Only mapped lexemes will be returned in any :class:`~sybil.Region` objects.
     """
 
     delimiter = '::'
 
-    def __init__(self, directive: str, arguments: str = '', mapping: Dict[str, str] = None):
+    def __init__(
+            self,
+            directive: str,
+            arguments: str = '',
+            mapping: Optional[Dict[str, str]] = None,
+    ) -> None:
         """
         A lexer for ReST directives.
         Both ``directive`` and ``arguments`` are regex patterns.
@@ -54,6 +72,11 @@ class DirectiveLexer(BlockLexer):
             mapping=mapping,
         )
 
+    def __call__(self, document: Document) -> Iterable[Region]:
+        for lexed in super().__call__(document):
+            parse_options_and_source(lexed)
+            yield lexed
+
 
 class DirectiveInCommentLexer(DirectiveLexer):
     """
@@ -80,8 +103,8 @@ class DirectiveInCommentLexer(DirectiveLexer):
 
     :param mapping:
         If provided, this is used to rename lexemes from the keys in the mapping to their values.
-        Only mapped lexemes will be returned in any :class:`~sybil.LexedRegion` objects.
+        Only mapped lexemes will be returned in any :class:`~sybil.Region` objects.
     """
 
     # This is the pattern used for invisible code blocks and the like.
-    delimiter = ':'
+    delimiter = ':?'
